@@ -26,6 +26,10 @@ LOG = logging.getLogger(__name__)
 # Internal ngs options will not be passed to driver.
 NGS_INTERNAL_OPTS = [
     {'name': 'ngs_mac_address'},
+    # Comma-separated list of names of interfaces to be added to each network.
+    {'name': 'ngs_trunk_ports'},
+    # Comma-separated list of physical networks to which this switch is mapped.
+    {'name': 'ngs_physical_networks'},
     {'name': 'ngs_ssh_connect_timeout', 'default': 60},
     {'name': 'ngs_ssh_connect_interval', 'default': 10},
     {'name': 'ngs_max_connections', 'default': 1},
@@ -73,14 +77,32 @@ class GenericSwitchDevice(object):
                 self.ngs_config[opt_name] = opt['default']
         self.config = device_cfg
 
+    def _get_trunk_ports(self):
+        """Return a list of trunk ports on this switch."""
+        trunk_ports = self.ngs_config.get('ngs_trunk_ports')
+        if not trunk_ports:
+            return []
+        return trunk_ports.split(',')
+
+    def _get_physical_networks(self):
+        """Return a list of physical networks mapped to this switch."""
+        physnets = self.ngs_config.get('ngs_physical_networks')
+        if not physnets:
+            return []
+        return physnets.split(',')
+
     @abc.abstractmethod
     def add_network(self, segmentation_id, network_id):
         pass
 
     @abc.abstractmethod
-    def del_network(self, segmentation_id):
+    def del_network(self, segmentation_id, network_id):
         pass
 
     @abc.abstractmethod
-    def plug_port_to_network(self, segmentation_id, port):
+    def plug_port_to_network(self, port_id, segmentation_id):
+        pass
+
+    @abc.abstractmethod
+    def delete_port(self, port_id, segmentation_id):
         pass
