@@ -15,6 +15,7 @@
 import fixtures
 import mock
 import netmiko
+import netmiko.base_connection
 from oslo_config import fixture as config_fixture
 import paramiko
 import tenacity
@@ -47,19 +48,33 @@ class TestNetmikoSwitch(NetmikoSwitchTestBase):
                 'NetmikoSwitch.send_commands_to_device')
     def test_add_network(self, m_sctd):
         self.switch.add_network(22, '0ae071f5-5be9-43e4-80ea-e41fefe85b21')
-        m_sctd.assert_called_with(None)
+        m_sctd.assert_called_with([])
+
+    @mock.patch('networking_generic_switch.devices.netmiko_devices.'
+                'NetmikoSwitch.send_commands_to_device')
+    def test_add_network_with_trunk_ports(self, m_sctd):
+        switch = self._make_switch_device({'ngs_trunk_ports': 'port1,port2'})
+        switch.add_network(22, '0ae071f5-5be9-43e4-80ea-e41fefe85b21')
+        m_sctd.assert_called_with([])
 
     @mock.patch('networking_generic_switch.devices.netmiko_devices.'
                 'NetmikoSwitch.send_commands_to_device')
     def test_del_network(self, m_sctd):
-        self.switch.del_network(22)
-        m_sctd.assert_called_with(None)
+        self.switch.del_network(22, '0ae071f5-5be9-43e4-80ea-e41fefe85b21')
+        m_sctd.assert_called_with([])
+
+    @mock.patch('networking_generic_switch.devices.netmiko_devices.'
+                'NetmikoSwitch.send_commands_to_device')
+    def test_del_network_with_trunk_ports(self, m_sctd):
+        switch = self._make_switch_device({'ngs_trunk_ports': 'port1,port2'})
+        switch.del_network(22, '0ae071f5-5be9-43e4-80ea-e41fefe85b21')
+        m_sctd.assert_called_with([])
 
     @mock.patch('networking_generic_switch.devices.netmiko_devices.'
                 'NetmikoSwitch.send_commands_to_device')
     def test_plug_port_to_network(self, m_sctd):
         self.switch.plug_port_to_network(2222, 22)
-        m_sctd.assert_called_with(None)
+        m_sctd.assert_called_with([])
 
     def test__format_commands(self):
         self.switch._format_commands(
@@ -129,22 +144,36 @@ class TestNetmikoSwitch(NetmikoSwitchTestBase):
         self.assertFalse(connect_mock.send_command.called)
 
     @mock.patch.object(netmiko_devices.NetmikoSwitch, '_get_connection')
-    def test_send_commands_to_device(self, gc_mock):
-        connect_mock = mock.MagicMock(SAVE_CONFIGURATION=None)
+    @mock.patch.object(netmiko_devices.NetmikoSwitch, 'send_config_set')
+    @mock.patch.object(netmiko_devices.NetmikoSwitch, 'save_configuration')
+    def test_send_commands_to_device(self, save_mock, send_mock, gc_mock):
+        connect_mock = mock.MagicMock(netmiko.base_connection.BaseConnection)
         gc_mock.return_value.__enter__.return_value = connect_mock
-        self.switch.send_commands_to_device(['spam ham aaaa'])
-        gc_mock.assert_called_once_with()
+        send_mock.return_value = 'fake output'
+        result = self.switch.send_commands_to_device(['spam ham aaaa'])
+        send_mock.assert_called_once_with(connect_mock, ['spam ham aaaa'])
+        self.assertEqual('fake output', result)
+        save_mock.assert_called_once_with(connect_mock)
+
+    def test_send_config_set(self):
+        connect_mock = mock.MagicMock(netmiko.base_connection.BaseConnection)
+        connect_mock.send_config_set.return_value = 'fake output'
+        result = self.switch.send_config_set(connect_mock, ['spam ham aaaa'])
+        connect_mock.enable.assert_called_once_with()
         connect_mock.send_config_set.assert_called_once_with(
             config_commands=['spam ham aaaa'])
+        self.assertEqual('fake output', result)
+
+    def test_save_configuration(self):
+        connect_mock = mock.MagicMock(netmiko.base_connection.BaseConnection)
+        self.switch.save_configuration(connect_mock)
         self.assertFalse(connect_mock.send_command.called)
 
-    @mock.patch.object(netmiko_devices.NetmikoSwitch, '_get_connection')
-    def test_send_commands_to_device_save_configuration(self, gc_mock):
-        connect_mock = mock.MagicMock(SAVE_CONFIGURAION='save me')
-        gc_mock.return_value.__enter__.return_value = connect_mock
-        self.switch.send_commands_to_device(['spam ham aaaa'])
-        connect_mock.send_config_set.assert_called_once_with(
-            config_commands=['spam ham aaaa'])
+    @mock.patch.object(netmiko_devices.NetmikoSwitch, 'SAVE_CONFIGURATION',
+                       'save me')
+    def test_save_configuration_required(self):
+        connect_mock = mock.MagicMock(netmiko.base_connection.BaseConnection)
+        self.switch.save_configuration(connect_mock)
         connect_mock.send_command.called_once_with('save me')
 
     @mock.patch.object(netmiko_devices.ngs_lock, 'PoolLock', autospec=True)
